using System;
using FitConnect;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using Moq;
using NUnit.Framework;

namespace InitializationTests;

public class BaseClassConstructorTests {
    private ILogger? _logger;

    [SetUp]
    public void Setup() {
        _logger = Mock.Of<ILogger>();
    }

    [Test]
    public void Sender_CreateCustomEndpoints() {
        var dut = new Sender(_logger, new FitConnectEndpoints(
            "http://localhost:5050/token",
            "http://localhost:5050/submission",
            "http://localhost:5050/routing"));

        dut.Endpoints.RoutingApi.Should().Be("http://localhost:5050/routing");
        dut.Endpoints.SubmissionApi.Should().Be("http://localhost:5050/submission");
        dut.Endpoints.TokenUrl.Should().Be("http://localhost:5050/token");
    }

    [Test]
    public void Sender_CreateDevEndpoints() {
        var dut = new Sender(_logger,
            FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Development));

        dut.Endpoints.TokenUrl.Should().Be("https://auth-testing.fit-connect.fitko.dev/token");
        dut.Endpoints.SubmissionApi.Should()
            .Be("https://submission-api-testing.fit-connect.fitko.dev");
        dut.Endpoints.RoutingApi.Should().Be("https://routing-api-testing.fit-connect.fitko.dev");
    }

    [Test]
    public void Sender_CreateTestingEndpoints_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
            var sender = new Subscriber(_logger,
                FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Testing));
        });
    }

    [Test]
    public void Sender_CreateProductionEndpoints_ShouldThrowArgumentException() {
        Assert.Throws<ArgumentException>(() => {
            var sender = new Sender(_logger,
                FitConnectEndpoints.Create(FitConnectEndpoints.EndpointType.Production));
        });
    }
}
